/*
	Spawn Enemy Attacks (SEA) - by Enigx
	
	Version: 1.0
	Author: Enigx
	Contributors: -
		
	SEA_OpenMe.sqf
		
	The system allows to generate random enemy attacks on SPECIFIC routes positioned on the map from the editor. Just place empty markers to set 
	one or more routes and run the script whenever you need.
	You can set the number of attacks and the time between them.
	Particularly useful to contrast attacks coming from specific directions and routes previously placed on map.
	Compatible with SP and MP.
	
	Steps needed for the system:
	1) Copy folder SEA_system\ into mission folder		
	2) Put empty markers on the map to identify the different routes of the waypoints of the enemy attacks.
	3) Name each routes of markers. Ex.
		- route 1: A_1 , A_2 , A_3 , A_4
		- route 2: B_1 , B_2 , B_3
		- route 3: C_1 , C_2 , C_3 , C_4 , C_5
		- ......
		NOTE: the first (i.e. A_1) is the spawing position, the last (i.e. A_4) the final position
		
	4) Compile the arrays and parameters here below to set the cycle of attacks (details reported below for each element)
	
	
HOW TO ACTIVATE THE SYSTEM
	-- By ACE self interaction menu.
		NOTE: OF COURSE YOU NEED THE ACE MOD LOADED IN YOUR MISSION TO USE THIS METHOD
		Initiate the commands for the execution of the SEA system from ACE self interaction menu.
		
		1) create initPlayerLocal.sqf in mission folder (if not already present)
		2) Add these strings in initPlayerLocal.sqf

			authPlayers = ["XXXXXX",...,"YYYYYY"];		// <-- ADD HERE THE STEAM ID OF THE PLAYER/S ENABLED TO ACTIVATE THE CYCLE OF ATTACKS BY ACE COMMANDS
			_uidP = getPlayerUID player;
			if (_uidP in authPlayers) then {
			    _actionP = {execVM "SEA_system\SEA_OpenMe.sqf";};
					_EnemyAttacks = ['EnemyAttacks', 'SEA Enemy Attacks', '', _actionP, {true}] call ace_interact_menu_fnc_createAction;
					[player, 1, ["ACE_SelfActions"], _EnemyAttacks] call ace_interact_menu_fnc_addActionToObject;
		
					_actionStop = {execVM "SEA_system\functions\Stop_SEA.sqf";};
					_StopEnemyAttacks = ['StopEnemyAttacks', 'SEA Stop Enemy Attacks', '', _actionStop, {true}] call ace_interact_menu_fnc_createAction;
					[player, 1, ["ACE_SelfActions"], _StopEnemyAttacks] call ace_interact_menu_fnc_addActionToObject;
				};
	
			NOTE: For obvious reasons not all players will be enabled to activate the cycle, but only the mission master with the specified ID
			Note: you have to run mission in MP also from editor to work with the Steam ID!
			Through the Ace menu, the cycle can be started also several times at the same time. By Ace menu you can also stop it in advance, 
			whenever you want, and start it again.
	
	-- By Triggers in editor
		 Alternatively, the cycle can be activated or stopped using triggers with the following instructions into their OnActivation field:

				null = execVM "SEA_system\SEA_OpenMe.sqf"; 					// TO START THE CYCLE
				null = execVM "SEA_system\functions\Stop_SEA.sqf"; 	// TO STOP THE CYCLE

	-- By debug console
		 Digit one of the two strings in previous bullet from Arma debug console when in game
	
*/

// ****** DO NOT MODIFY *************
private ["_arrayUnits","_arrayVeh","_arrayMark","_iter","_numAttacks","_timeAttacks","_sideF"];
consecutiveAttacks = 0;
publicVariable "consecutiveAttacks";
// ***********************************


// %%%%%%%%%% SECTION TO BE MODIFIED %%%%%%%%%%%%%%%%%%%%%%
// Cycle duration parameters
_numAttacks = 5; 	// <-- SET THE DESIRED NUMBER OF ATTACKS
_timeAttacks = 10; 	// <-- SET THE TIME IN SECONDS BETWEEN ONE ATTACK AND THE OTHER

// Type of faction (east, independent, civilian, west)
_sideF = east;			// <-- SET THE FACTION

// Array of infantry units
// SET THE DIFFERENT FIRE TEAMS THAT WILL ATTACK (at least one must be specified). The system will select a random one from time to time
_arrayUnits =
[
["O_SoldierU_SL_F","O_soldierU_repair_F"],
["O_soldierU_medic_F","O_sniper_F","O_Soldier_A_F"],
["O_Soldier_AAT_F","O_Soldier_AR_F","O_Soldier_AT_F","O_soldier_exp_F"],
["O_engineer_F","O_engineer_U_F","O_medic_F"],
["O_Soldier_AA_F","O_Soldier_AAA_F","O_Soldier_AAR_F"]
];


// Array of vehicles
// SET THE GROUND VEHICLES TO BE USED BY THE TEAMS IN THE ATTACK. The system selects a random one from time to time
// **** NOTE: AT LEAST ONE vehicle must always be indicated, even if not used, as for example in attacks with only infantry !!
// **** NOTE: IF TEAM IN THE CAR, THE FIRST UNIT IS ASSIGNED AS A DRIVER, THE SECOND AS A GUNNER (IF VEHICLE EQUIPPED WITH GUNNER POSTATION)
// **** IF IN THE CAR, BE CAREFUL TO USE A CONGRUATE NUMBER OF UNITS ACCORDING TO ITS CAPACITY, OTHERWISE THE REMAINING REMAINS OUTSIDE THE VEHICLE !!
_arrayVeh = ["O_Truck_02_covered_F","O_Truck_02_transport_F","O_MRAP_02_F","O_MRAP_02_gmg_F","O_MRAP_02_hmg_F"];

/* Array of the use or not of vehicle for the attack
NOTE: 
	-	if you want only foot infantry units modify as: _arrayVehPres = [0];
	-	if you want only units on vehicles modify as: _arrayVehPres = [1];
	- if you want random (vehicle or on foot) modify as: _arrayVehPres = [0,1];
*/
_arrayVehPres = [0,1];

// Array of the waypoint routes of markers
// SET THE DIFFERENT ROUTES OF THE ATTACKS (at least one must be specified). The system selects a random one from time to time
// THE NAMES OF THE MARKERS MUST BE DEFINED AND PLACED ON THE MAP IN ADVANCE DURING THE EDITING PHASE OF THE MISSION
_arrayMark =
[
["A_1","A_2","A_3","A_4"],
["B_1","B_2","B_3","B_4"],
["C_1","C_2","C_3","C_4","C_5"],
["D_1","D_2","D_3"]
];

// Array setting the behavior at the last waypoint
// NOTE: if you want only one behavior, modify it with only the desired behavior, ex.: _comport = ["MOVE"];
// NOTE: "GETOUT" is used for vehicle attacks to get out units from it once at last waypoint. If used for infantry, units will simply go to selected waypoint
_comport = ["GETOUT","MOVE"];

// %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


// ****** DO NOT MODIFY *************
hint "CYCLE OF ATTACKS STARTED"; // only the player who activates the system sees the message
_iter = 0;
while {!(_iter ==  _numAttacks) and (consecutiveAttacks == 0)} do {
null = [selectRandom _arrayVeh,selectRandom _arrayVehPres,selectRandom _arrayUnits,selectRandom _arrayMark,_sideF,selectRandom _comport] execVM "SEA_system\functions\Spawn_Enemy_attack_V2.sqf";
sleep _timeAttacks;
_iter = _iter + 1;
};
hint "CYCLE OF ATTACKS ENDED"; // message that warns the player that the cycle has ended / interrupted (only the player who activates the system sees the message) 
// ***********************************
